@@ -14,11 +14,13 @@ logger = get_logger(__name__)
 class TranscriptionResponseFormat(Enum):
     JSON = 'JSON'
     PLAIN = 'PLAIN'
+    DOCX = 'DOCX'
 
 
 class TranscriptionRequest:
     def __init__(self, file_uid: str,
                  file_path: Union[str, Path],
+                 file_name: str,
                  model: Model,
                  success_url: Optional[str] = None,
                  fail_url: Optional[str] = None,
@@ -36,6 +38,7 @@ class TranscriptionRequest:
                  **kwargs):
         assert file_uid is not None
         assert file_path is not None
+        assert file_name is not None
         assert model is not None
         assert transcript_format is not None
         assert not speakers_diarization or not multi_channels, 'Speakers diarization and multi-channels cannot' \
@@ -44,6 +47,7 @@ class TranscriptionRequest:
         self.uid = str(uuid.uuid4())
         self.file_uid: str = file_uid
         self.file_path: str = str(file_path)
+        self.file_name: str = file_name
         self.model: Model = model
         self.success_url: Optional[str] = success_url
         self.fail_url: Optional[str] = fail_url
@@ -78,6 +82,10 @@ class TranscriptionRequest:
     def __repr__(self):
         return self.__str__()
 
+    @property
+    def stemmed_file_name(self) -> str:
+        return Path(self.file_name).stem
+
 
 class TranscriptionResponse:
 
